@@ -9,6 +9,7 @@ use crate::{config::LintConfig, rule::Rule};
 mod const_assign;
 mod duplicate_bindings;
 mod duplicate_exports;
+mod no_dupe_args;
 mod utils;
 
 #[cfg(feature = "non_critical_lints")]
@@ -41,6 +42,7 @@ pub fn all(lint_params: LintParams) -> Vec<Box<dyn Rule>> {
         const_assign::const_assign(),
         duplicate_bindings::duplicate_bindings(),
         duplicate_exports::duplicate_exports(),
+        no_dupe_args::no_dupe_args(),
     ];
 
     #[cfg(feature = "non_critical_lints")]
